@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 import abc
-from typing import Union
+from typing import Union, List
 
 from pydantic import BaseModel
 
@@ -13,7 +13,7 @@ class IJceStruct(BaseModel, abc.ABC):
     """
 
     @abc.abstractmethod
-    def read_from(self, reader: JceReader):
+    def read_from(self, reader: JceReader) -> None:
         raise NotImplementedError
 
     @abc.abstractmethod
